@@ -18,7 +18,7 @@ def from_dict(obj):
     @param obj: dict
     @return: Object
     """
-    if '_className' in obj:
+    if '_className' in obj and obj['_className']:
         module, name = module_name_from_class(obj['_className'])
 
         try:
@@ -46,4 +46,4 @@ class Object(object):
         return '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__))
 
     def datetime(self, unixtime):
-        return datetime.fromtimestamp(int(unixtime))
\ No newline at end of file
+        return datetime.fromtimestamp(int(unixtime))
