@@ -175,7 +175,12 @@ class Shop(Service):
         """
         return self._callapi("shop/products/search", get={"query": query})
 
-    def get_products_list(self, category=None, products=None):
+    def get_products_list(
+            self,
+            category=None,
+            products=None,
+            ingredient=None,
+            random=None):
         """
         :rtype : list of Product|Collection
         """
@@ -183,7 +188,9 @@ class Shop(Service):
             "shop/products",
             get={
                 "category": category,
-                "products": products})
+                "products": products,
+                "ingredient": ingredient,
+                "random": random})
 
     def check_promo_code(self, code):
         """
